@@ -40,10 +40,13 @@ def map_json(mapping_config, json_data, strict=False):
                 key, prop = get_loop_params(key)
                 list_result = []
                 list_json = walk_dict(json_data, key, strict)
-                for lj in list_json:
-                    list_result.append(
-                        map_json(config, lj)
-                    )
+                if dict == type(list_json):
+                    list_result.append(map_json(config, list_json))
+                elif list == type(list_json):
+                    for lj in list_json:
+                        list_result.append(
+                            map_json(config, lj)
+                        )
                 result[prop] = list_result
             else:
                 result.update(
@@ -58,7 +61,7 @@ def map_json(mapping_config, json_data, strict=False):
                     data = list_json.get(config)
                     if data:
                         list_result.append(data)
-                else:
+                elif list == type(list_json):
                     for lj in list_json:
                         if config in lj:
                             list_result.append(lj[config])
